@@ -1,10 +1,12 @@
 from django.contrib import admin
+from django.contrib.auth import get_user_model
 
 from auditlog.filters import ResourceTypeFilter
 from auditlog.mixins import LogEntryAdminMixin
 from auditlog.models import LogEntry
 
 
+@admin.register(LogEntry)
 class LogEntryAdmin(admin.ModelAdmin, LogEntryAdminMixin):
     list_select_related = ["content_type", "actor"]
     list_display = ["created", "resource_url", "action", "msg_short", "user_url"]
@@ -14,7 +16,7 @@ class LogEntryAdmin(admin.ModelAdmin, LogEntryAdminMixin):
         "changes",
         "actor__first_name",
         "actor__last_name",
-        "actor__username",
+        f"actor__{get_user_model().USERNAME_FIELD}",
     ]
     list_filter = ["action", ResourceTypeFilter]
     readonly_fields = ["created", "resource_url", "action", "user_url", "msg"]
@@ -24,8 +26,10 @@ class LogEntryAdmin(admin.ModelAdmin, LogEntryAdminMixin):
     ]
 
     def has_add_permission(self, request):
-        # As audit admin doesn't allow log creation from admin
         return False
 
+    def has_change_permission(self, request, obj=None):
+        return False
 
-admin.site.register(LogEntry, LogEntryAdmin)
+    def has_delete_permission(self, request, obj=None):
+        return False
